/*
 *    (c) Copyright 2016 Cisco Systems
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
(function () {
  'use strict';

  angular
    .module('horizon.framework.util.uuid', [])
    .factory('horizon.framework.util.uuid.service', uuidService);

  /**
   * @name horizon.framework.util.uuid
   * @description
   * Generates a UUID. This is useful for ensuring HTML components
   * have unique IDs for interactions.
   */
  function uuidService() {
    return {
      generate: horizon.uuid.generate
    };
  }
})();
